@@ -78,8 +78,8 @@ def _assert_fail_message(message, expected, actual, comparison_str, extra):
     if message:
         return message
     if extra:
-        return "%r %s %r (%s)" % (expected, comparison_str, actual, extra)
-    return "%r %s %r" % (expected, comparison_str, actual)
+        return "%a %s %a (%s)" % (expected, comparison_str, actual, extra)
+    return "%a %s %a" % (expected, comparison_str, actual)
 
 
 def assert_is(expected, actual, message=None, extra=None):
@@ -117,25 +117,30 @@ def assert_eq(expected, actual, message=None, tolerance=None, extra=None):
         )
     else:
         assert isinstance(tolerance, _number_types), (
-            "tolerance parameter to assert_eq must be a number: %r" % tolerance
+            "tolerance parameter to assert_eq must be a number: %a" % tolerance
         )
         assert isinstance(expected, _number_types) and isinstance(
             actual, _number_types
-        ), "parameters must be numbers when tolerance is specified: %r, %r" % (
+        ), "parameters must be numbers when tolerance is specified: %a, %a" % (
             expected,
             actual,
         )
 
         diff = abs(expected - actual)
         assert diff <= tolerance, _assert_fail_message(
-            message, expected, actual, "is more than %r away from" % tolerance, extra
+            message, expected, actual, "is more than %a away from" % tolerance, extra
         )
 
 
 def _dict_path_string(path):
     if len(path) == 0:
         return "(root)"
-    return "->".join(map(repr, path))
+    return "->".join(map(ascii, path))
+
+
+def _to_concrete_dict(value):
+    """Convert dict-subclass instances to concrete dict instances."""
+    return dict(value) if isinstance(value, dict) and type(value) is not dict else value
 
 
 def assert_dict_eq(expected, actual, number_tolerance=None, dict_path=[]):
@@ -145,46 +150,50 @@ def assert_dict_eq(expected, actual, number_tolerance=None, dict_path=[]):
 
     expected_keys = set(expected.keys())
     actual_keys = set(actual.keys())
-    assert expected_keys <= actual_keys, "Actual dict at %s is missing keys: %r" % (
+    assert expected_keys <= actual_keys, "Actual dict at %s is missing keys: %a" % (
         _dict_path_string(dict_path),
         expected_keys - actual_keys,
     )
-    assert actual_keys <= expected_keys, "Actual dict at %s has extra keys: %r" % (
+    assert actual_keys <= expected_keys, "Actual dict at %s has extra keys: %a" % (
         _dict_path_string(dict_path),
         actual_keys - expected_keys,
     )
 
-    for k in expected_keys:
-        key_path = dict_path + [k]
+    for key in expected_keys:
+        key_path = dict_path + [key]
+
+        expected_value = _to_concrete_dict(expected[key])
+        actual_value = _to_concrete_dict(actual[key])
+
         assert_is_instance(
-            actual[k],
-            type(expected[k]),
+            actual_value,
+            type(expected_value),
             extra="Types don't match for %s" % _dict_path_string(key_path),
         )
         assert_is_instance(
-            expected[k],
-            type(actual[k]),
+            expected_value,
+            type(actual_value),
             extra="Types don't match for %s" % _dict_path_string(key_path),
         )
 
-        if isinstance(actual[k], dict):
+        if isinstance(actual_value, dict):
             assert_dict_eq(
-                expected[k],
-                actual[k],
+                expected_value,
+                actual_value,
                 number_tolerance=number_tolerance,
                 dict_path=key_path,
             )
-        elif isinstance(actual[k], _number_types):
+        elif isinstance(actual_value, _number_types):
             assert_eq(
-                expected[k],
-                actual[k],
+                expected_value,
+                actual_value,
                 extra="Value doesn't match for %s" % _dict_path_string(key_path),
                 tolerance=number_tolerance,
             )
         else:
             assert_eq(
-                expected[k],
-                actual[k],
+                expected_value,
+                actual_value,
                 extra="Value doesn't match for %s" % _dict_path_string(key_path),
             )
 
@@ -203,18 +212,18 @@ def assert_ne(expected, actual, message=None, tolerance=None, extra=None):
         )
     else:
         assert isinstance(tolerance, _number_types), (
-            "tolerance parameter to assert_eq must be a number: %r" % tolerance
+            "tolerance parameter to assert_eq must be a number: %a" % tolerance
         )
         assert isinstance(expected, _number_types) and isinstance(
             actual, _number_types
-        ), "parameters must be numbers when tolerance is specified: %r, %r" % (
+        ), "parameters must be numbers when tolerance is specified: %a, %a" % (
             expected,
             actual,
         )
 
         diff = abs(expected - actual)
         assert diff > tolerance, _assert_fail_message(
-            message, expected, actual, "is less than %r away from" % tolerance, extra
+            message, expected, actual, "is less than %a away from" % tolerance, extra
         )
 
 
@@ -292,7 +301,7 @@ def assert_unordered_list_eq(expected, actual, message=None):
     if missing_in_actual or missing_in_expected:
         if not message:
             message = (
-                "%r not equal to %r; missing items: %r in expected, %r in actual."
+                "%a not equal to %a; missing items: %a in expected, %a in actual."
                 % (expected, actual, missing_in_expected, missing_in_actual)
             )
         assert False, message
