@@ -271,6 +271,7 @@ def lru_cache(maxsize=128, key_fn=None):
                 return value
 
         wrapper.clear = cache.clear
+        wrapper.fn = fn
 
         return wrapper
 
@@ -313,6 +314,7 @@ def cached_per_instance():
 
         # just so unit tests can check that this is cleaned up correctly
         new_fun.__cached_per_instance_cache__ = cache
+        new_fun.fn = fun
         return new_fun
 
     return cache_fun
@@ -331,6 +333,9 @@ def get_args_tuple(args, kwargs, arg_names, kwargs_defaults):
             else:
                 args_list.append(kwargs[arg_name])
             args_len += 1
+        remaining_keys = sorted([k for k in kwargs if k not in arg_names])
+        for k in remaining_keys:
+            args_list.append((k, kwargs[k]))
     except KeyError as e:
         raise TypeError("Missing argument %r" % (e.args[0],))
     return tuple(args_list)
@@ -376,6 +381,7 @@ def memoize(fun):
 
     new_fun.__cache = {}
     new_fun.clear_cache = clear_cache
+    new_fun.fn = fun
     return new_fun
 
 
@@ -439,6 +445,7 @@ def memoize_with_ttl(ttl_secs=60 * 60 * 24):
         new_fun.__cache_times = {}
         new_fun.clear_cache = clear_cache
         new_fun.dirty = dirty
+        new_fun.fn = fun
         return new_fun
 
     return cache_fun
